stch.glob

Contains a simple glob matching fn. Credit to https://github.com/jkk/clj-glob.

Contains a simple glob matching fn. Credit to
https://github.com/jkk/clj-glob.
raw docstring

and-notcljmacro

(and-not & forms)
source

compile-patternclj

(compile-pattern pattern)

Takes a glob pattern as a string and returns a regex pattern.

Takes a glob pattern as a string and returns a regex pattern.
sourceraw docstring

compile-pattern*cljmacro

(compile-pattern* pattern)

Takes a glob pattern as a string and returns a regex pattern. If a string is passed, the glob pattern can be compiled to a regex at macro expansion time.

Takes a glob pattern as a string and returns a regex pattern.
If a string is passed, the glob pattern can be compiled to a regex
at macro expansion time.
sourceraw docstring

compiled-pattern?clj

(compiled-pattern? x)
source

match-globclj

(match-glob pattern s)

Attempt to match a string with the given glob pattern. Returns the matched string on success, otherwise nil.

Attempt to match a string with the given glob pattern.
Returns the matched string on success, otherwise nil.
sourceraw docstring

match-globfclj

(match-globf pattern path)

Attempt to match the file path with the given glob pattern. Returns the matched portion on success, otherwise nil. Pattern and path must be strings.

Attempt to match the file path with the given glob pattern.
Returns the matched portion on success, otherwise nil.
Pattern and path must be strings.
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries