Contains a simple glob matching fn. Credit to https://github.com/jkk/clj-glob.
Contains a simple glob matching fn. Credit to https://github.com/jkk/clj-glob.
(compile-pattern pattern)Takes a glob pattern as a string and returns a regex pattern.
Takes a glob pattern as a string and returns a regex pattern.
(compile-pattern* pattern)Takes a glob pattern as a string and returns a regex pattern. If a string is passed, the glob pattern can be compiled to a regex at macro expansion time.
Takes a glob pattern as a string and returns a regex pattern. If a string is passed, the glob pattern can be compiled to a regex at macro expansion time.
(match-glob pattern s)Attempt to match a string with the given glob pattern. Returns the matched string on success, otherwise nil.
Attempt to match a string with the given glob pattern. Returns the matched string on success, otherwise nil.
(match-globf pattern path)Attempt to match the file path with the given glob pattern. Returns the matched portion on success, otherwise nil. Pattern and path must be strings.
Attempt to match the file path with the given glob pattern. Returns the matched portion on success, otherwise nil. Pattern and path must be strings.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |